# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ciphey',
 'ciphey.basemods',
 'ciphey.basemods.Checkers',
 'ciphey.basemods.Crackers',
 'ciphey.basemods.Decoders',
 'ciphey.basemods.Resources',
 'ciphey.basemods.Searchers',
 'ciphey.iface']

package_data = \
{'': ['*']}

install_requires = \
['appdirs>=1.4.4,<2.0.0',
 'base58>=2.0.1,<3.0.0',
 'cipheycore>=0.2.3,<0.3.0',
 'cipheydists>=0.3.10,<0.4.0',
 'click-spinner>=0.1.10,<0.2.0',
 'click>=7.1.2,<8.0.0',
 'flake8>=3.8.2,<4.0.0',
 'loguru>=0.5.0,<0.6.0',
 'pybase62>=0.4.3,<0.5.0',
 'pylint>=2.5.2,<3.0.0',
 'pyyaml>=5.3.1,<6.0.0',
 'rich>=1.2.3,<2.0.0',
 'yaspin>=0.17.0,<0.18.0']

extras_require = \
{':python_version >= "3.6" and python_version < "3.8"': ['typing_inspect>=0.6.0,<0.7.0']}

entry_points = \
{'console_scripts': ['ciphey = ciphey.ciphey:main']}

setup_kwargs = {
    'name': 'ciphey',
    'version': '5.0.0rc10',
    'description': 'Automated Decryption Tool',
    'long_description': '<p align="center">\n➡️ \n<a href="https://docs.ciphey.online">Documentation</a> |\n<a href="https://discord.ciphey.online">Discord</a> |\n <a href="https://docs.ciphey.online/en/latest/install.html">Installation Guide</a>\n ⬅️\n\n<br>\n  <img src="Pictures_for_README/binoculars.png" alt="Ciphey">\n</p>\n\n<p align="center">\n  <img alt="GitHub commit activity" src="https://img.shields.io/github/commit-activity/m/ciphey/ciphey">\n<img src="https://pepy.tech/badge/ciphey">\n <img src="https://pepy.tech/badge/ciphey/month">\n  <a href="https://discord.gg/wM3scnc"><img alt="Discord" src="https://img.shields.io/discord/728245678895136898"></a>\n<a href="https://pypi.org/project/ciphey/"><img src="https://img.shields.io/pypi/v/ciphey.svg"></a>\n  <img src="https://img.shields.io/badge/License-MIT-yellow.svg" alt="Ciphey">\n  \n  <img src="https://github.com/brandonskerritt/Ciphey/workflows/Python%20application/badge.svg?branch=master" alt="Ciphey">\n<br>\nFully automated decryption tool using natural language processing & artifical intelligence, along with some common sense.\n</p>\n<hr>\n\n## [Installation Guide](https://docs.ciphey.online/en/latest/install.html)\n\n**NOTE** This README is being worked on for version 5. You can only install Ciphey via PyPi at the moment.\n\n| <p align="center"><a href="https://pypi.org/project/ciphey">🐍 Python (Universal) </a></p> | <p align="center"><a href="https://pypi.org/project/ciphey"> Arch </a></p> | <p align="center"><a href="https://pypi.org/project/ciphey"> Windows </a></p>  |\n| ----------------------------------------------------------------------------------------- | -------------------------------------------------------------------------- | ----------------------------------------------------------------------------- |\n| <p align="center"><img src="Pictures_for_README/python.png" /></p>                        | <p align="center"><img src="Pictures_for_README/arch.png" /></p>           | <p align="center"><img src="Pictures_for_README/windows.png" /></p>                      |\n| `python3 -m pip install ciphey --upgrade`                                                 | `yay ciphey`                                                               | `winget ciphey`                                                               | \n\n| Linux       | Mac OS | Windows     |\n| ----------- | ------ | ----------- |\n| ![GitHub Workflow Status](https://img.shields.io/github/workflow/status/ciphey/ciphey/Python%20application?label=Linux) |![GitHub Workflow Status](https://img.shields.io/github/workflow/status/ciphey/ciphey/Python%20application?label=Mac%20OS) | ![GitHub Workflow Status](https://img.shields.io/github/workflow/status/ciphey/ciphey/Python%20application?label=Windows) |\n  \n\n<hr>\n\n# 🤔 What is this?\nCiphey is an automated decryption tool. Input encrypted text, get the decrypted text back.\n> "What type of encryption?"\n\nThat\'s the point. You don\'t know, you just know it\'s possibly encrypted. Ciphey will figure it out for you.\n\nCiphey can solve most things in 3 seconds or less.\n\n<p align="center" href="https://asciinema.org/a/336257">\n  <img src="Pictures_for_README/index.gif" alt="Ciphey demo">\n</p>\n\n**The technical part.** Ciphey uses a custom built artifical intelligence module (_AuSearch_) with a _Cipher Detection Interface_ to approximate what something is encrypted with. And then a custom-built, customisable natural languge processing _Language Checker Interface_, which can detect when the given text becomes plaintext.\n\nAnd that\'s just the tip of the iceberg. For the full technical explanation, check out our [documentation](https://docs.ciphey.online/en/latest/howWork.html).\n\n# ✨ Features\n\n- **20+ encryptions supported** such as hashes, encodings (binary, base64) and normal encryptions like Caesar cipher, Transposition and more. **[For the full list, click here](https://docs.ciphey.online/en/latest/ciphers.html)**\n- **Custom Built Artificial Intelligence with Augmented Search (AuSearch) for answering the question "what encryption was used?"** Resulting in decryptions taking less than 3 seconds. \n- **Custom built natural language processing module** Ciphey can determine whether something is plaintext or not. It has an incredibly high accuracy, along with being fast.\n- **Multi Language Support** at present, only German & English (with AU, UK, CAN, USA variants).\n- **Supports hashes & encryptions** Which the alternatives such as CyberChef Magic do not. \n- **[C++ core](https://github.com/Ciphey/CipheyCore)** Blazingly fast.\n\n# 🔭 Ciphey vs CyberChef\n\n## 🔁 Base64 Encoded 64 times\n\n<table>\n  <tr>\n  <th>Name</th>\n    <th>⚡ Ciphey ⚡ </th>\n    <th>🐢 CyberChef 🐢</th>\n  </tr>\n  <tr>\n  <th>Gif</th>\n    <td><img src="Pictures_for_README/ciphey_vs_cyberchef.gif" alt="The guy she tells you not to worry about"></td>\n    <td><img src="Pictures_for_README/not_dying.gif" alt="You"></td>\n  </tr>\n  <tr>\n  <th>Time</th>\n    <td>4 seconds</td>\n    <td>6 seconds</td>\n  </tr>\n    <tr>\n  <th>Setup</th>\n    <td><ul><li>Set the regex param to "{"</li></ul></td>\n    <td><ul><li>Set the regex param to "{"</li><li>You need to know how many times to recurse</li><li>You need to know it\'s Base64 all the way down</li><li>You need to load CyberChef (it\'s a bloated JS app)</li><li>Know enough about CyberChef to create this pipeline</li><li>Invert the match</li></ul></td>\n  </tr>\n</table>\n\n\n<sub><b>Note</b> The gifs may load at different times, so one may appear significantly faster than another.</sub><br>\n<sub><b>A note on magic </b>CyberChef\'s most similar feature to Ciphey is Magic. Magic fails instantly on this input and crashes. The only way we could force CyberChef to compete was to manually define it.</sub>\n\n\nWe also tested CyberChef and Ciphey with a **6gb file**. Ciphey cracked it in **5 minutes and 54 seconds**. CyberChef crashed before it even started.\n\n\n\n## 📊 Ciphey vs Katana vs CyberChef Magic\n\n| **Name**                                   | ⚡ Ciphey ⚡ | 🤡 Katana 🤡 | 🐢 CyberChef Magic 🐢 |\n| ------------------------------------------ | ---------- | ---------- | ------------------- |\n| Advanced Language Checker                   | ✅          | ❌          | ✅                   |\n| Supports Encryptions                       | ✅          | ✅          | ❌                   |\n| Releases named after Dystopian themes 🌃    | ✅          | ❌          | ❌                   |\n| Supports hashes                            | ✅          | ✅          | ❌                   |\n| Easy to set up                             | ✅          | ❌          | ✅                   |\n| Can guess what something is encrypted with | ✅          | ❌          | ❌                   |\n| Created for hackers by hackers             | ✅          | ✅          | ❌                   |\n\n# 🎬 Getting Started\n\nIf you\'re having trouble with installing Ciphey, [read this.](https://docs.ciphey.online/en/latest/install.html)\n\n## ‼️ Important Links (Docs, Installation guide, Discord Support)\n\n| Installation Guide | Documentation | Discord |\n| ------------------ | ------------- | ------- |\n| 📖 [Installation Guide](https://docs.ciphey.online/en/latest/install.html) | 📚 [Documentation](https://docs.ciphey.online) | 🦜 [Discord](https://discord.ciphey.online)\n\n## 🏃\u200d♀️Running Ciphey\nThere are 3 ways to run Ciphey.\n1. File Input `ciphey - encrypted.txt`\n2. Unqualified input `ciphey -- "Encrypted input`\n3. Normal way `ciphey -t "Encrypted input"`\n\n![Gif showing 3 ways to run Ciphey](Pictures_for_README/3ways.gif)\n\nTo get rid of the progress bars, probability table, and all the noise use the quiet mode.\n\n```ciphey -t "encrypted text here" -q```\n\nFor a full list of arguments, run `ciphey --help`.\n\n### ⚗️ Importing Ciphey\nYou can import Ciphey\\\'s main and use it in your own programs and code. `from Ciphey.__main__ import main`\n\n# 🎪 Contributors\nCiphey was invented by [Brandon Skerritt](https://github.com/brandonskerritt) in 2008, and revived in 2019. Ciphey wouldn\'t be where it was today without [Cyclic3](https://github.com/Cyclic3) - president of UoL\'s Cyber Security Society.\n\nCiphey was revived & recreated by the [Cyber Security Society](https://www.cybersoc.cf/) for use in CTFs. If you\'re ever in Liverpool, consider giving a talk or sponsoring our events. Email us at `cybersecurity@society.liverpoolguild.org` to find out more 🤠\n\n**Major Credit** to George H for designing the searching algorithm among other things.\n**Special thanks** to [varghalladesign](https://www.facebook.com/varghalladesign) for designing the logo. Check out their other design work!\n\n## 🐕\u200d🦺 [Contributing](CONTRIBUTING.md)\nDon\'t be afraid to contribute! We have many, many things you can do to help out. Each of them labelled and easily explained with examples. If you\'re trying to contribute but stuck, tag @brandonskerritt in the GitHub issue ✨\n\nAlternatively, join the Discord group and send a message there (link in [contrib file](CONTRIBUTING.md)) or at the top of this README as a badge.\n\nPlease read the [contributing file](CONTRIBUTING.md) for exact details on how to contribute ✨\n## 💰 Financial Contributors\nThe contributions will be used to fund not only the future of Ciphey and its authors, but also Cyber Security Society at the University of Liverpool.\n\nGitHub doesn\'t support "sponsor this project and we\'ll evenly distribute the money", so pick a link and we\'ll sort it out on our end 🥰\n\n## ✨ Contributors\n\nThanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):\n\n<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->\n<!-- prettier-ignore-start -->\n<!-- markdownlint-disable -->\n<table>\n  <tr>\n    <td align="center"><a href="https://skerritt.blog"><img src="https://avatars3.githubusercontent.com/u/10378052?v=4" width="100px;" alt=""/><br /><sub><b>Brandon</b></sub></a><br /><a href="#design-brandonskerritt" title="Design">🎨</a> <a href="#maintenance-brandonskerritt" title="Maintenance">🚧</a> <a href="https://github.com/Ciphey/Ciphey/commits?author=brandonskerritt" title="Code">💻</a> <a href="#ideas-brandonskerritt" title="Ideas, Planning, & Feedback">🤔</a></td>\n    <td align="center"><a href="https://github.com/Cyclic3"><img src="https://avatars1.githubusercontent.com/u/15613874?v=4" width="100px;" alt=""/><br /><sub><b>cyclic3</b></sub></a><br /><a href="#design-cyclic3" title="Design">🎨</a> <a href="#maintenance-cyclic3" title="Maintenance">🚧</a> <a href="https://github.com/Ciphey/Ciphey/commits?author=cyclic3" title="Code">💻</a> <a href="#ideas-cyclic3" title="Ideas, Planning, & Feedback">🤔</a></td>\n    <td align="center"><a href="https://github.com/michalani"><img src="https://avatars0.githubusercontent.com/u/27767884?v=4" width="100px;" alt=""/><br /><sub><b>michalani</b></sub></a><br /><a href="https://github.com/Ciphey/Ciphey/commits?author=michalani" title="Code">💻</a></td>\n    <td align="center"><a href="https://github.com/ashb07"><img src="https://avatars2.githubusercontent.com/u/24845568?v=4" width="100px;" alt=""/><br /><sub><b>ashb07</b></sub></a><br /><a href="https://github.com/Ciphey/Ciphey/commits?author=ashb07" title="Code">💻</a></td>\n  </tr>\n</table>\n\n<!-- markdownlint-enable -->\n<!-- prettier-ignore-end -->\n<!-- ALL-CONTRIBUTORS-LIST:END -->\n\nThis project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!\n',
    'author': 'Brandon',
    'author_email': 'brandon@skerritt.blog',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
